==> kaffe-0.10.1_1998-07-13.tar.gz: kaffe-0.10.1_1998-07-13/libraries/clib/native/external_wrappers.h <==
KAFFE_NATIVE(java_lang_reflect_Array_getLength)
KAFFE_NATIVE(java_lang_reflect_Array_get)
KAFFE_NATIVE(java_lang_reflect_Array_getBoolean)
KAFFE_NATIVE(java_lang_reflect_Array_getByte)
KAFFE_NATIVE(java_lang_reflect_Array_getChar)
KAFFE_NATIVE(java_lang_reflect_Array_getShort)
KAFFE_NATIVE(java_lang_reflect_Array_getInt)
KAFFE_NATIVE(java_lang_reflect_Array_getLong)
KAFFE_NATIVE(java_lang_reflect_Array_getFloat)
KAFFE_NATIVE(java_lang_reflect_Array_getDouble)
KAFFE_NATIVE(java_lang_reflect_Array_set)
KAFFE_NATIVE(java_lang_reflect_Array_setBoolean)
KAFFE_NATIVE(java_lang_reflect_Array_setByte)
KAFFE_NATIVE(java_lang_reflect_Array_setChar)
KAFFE_NATIVE(java_lang_reflect_Array_setShort)
KAFFE_NATIVE(java_lang_reflect_Array_setInt)
KAFFE_NATIVE(java_lang_reflect_Array_setLong)
KAFFE_NATIVE(java_lang_reflect_Array_setFloat)
KAFFE_NATIVE(java_lang_reflect_Array_setDouble)
KAFFE_NATIVE(java_lang_reflect_Array_newArray)
KAFFE_NATIVE(java_lang_reflect_Array_multiNewArray)
KAFFE_NATIVE(java_lang_Class_forName)
KAFFE_NATIVE(java_lang_Class_getName)
KAFFE_NATIVE(java_lang_Class_newInstance)
KAFFE_NATIVE(java_lang_Class_getSuperclass)
KAFFE_NATIVE(java_lang_Class_getInterfaces)
KAFFE_NATIVE(java_lang_Class_getClassLoader)
KAFFE_NATIVE(java_lang_Class_isInterface)
KAFFE_NATIVE(java_lang_Class_isPrimitive)
KAFFE_NATIVE(java_lang_Class_isArray)
KAFFE_NATIVE(java_lang_Class_getComponentType)
KAFFE_NATIVE(java_lang_Class_isAssignableFrom)
KAFFE_NATIVE(java_lang_Class_getPrimitiveClass)
KAFFE_NATIVE(java_lang_Class_isInstance)
KAFFE_NATIVE(java_lang_Class_getModifiers)
KAFFE_NATIVE(java_lang_Class_getSigners)
KAFFE_NATIVE(java_lang_Class_setSigners)
KAFFE_NATIVE(java_lang_Class_getMethods0)
KAFFE_NATIVE(java_lang_Class_getConstructors0)
KAFFE_NATIVE(java_lang_Class_getFields0)
KAFFE_NATIVE(java_lang_Class_getMethod0)
KAFFE_NATIVE(java_lang_Class_getConstructor0)
KAFFE_NATIVE(java_lang_Class_getField0)
KAFFE_NATIVE(java_lang_ClassLoader_init)
KAFFE_NATIVE(java_lang_ClassLoader_defineClass0)
KAFFE_NATIVE(java_lang_ClassLoader_resolveClass0)
KAFFE_NATIVE(java_lang_ClassLoader_findSystemClass0)
KAFFE_NATIVE(java_lang_ClassLoader_getSystemResourceAsStream0)
KAFFE_NATIVE(java_lang_ClassLoader_getSystemResourceAsName0)
KAFFE_NATIVE(java_lang_Compiler_initialize)
KAFFE_NATIVE(java_lang_Compiler_compileClass)
KAFFE_NATIVE(java_lang_Compiler_compileClasses)
KAFFE_NATIVE(java_lang_Compiler_command)
KAFFE_NATIVE(java_lang_Compiler_enable)
KAFFE_NATIVE(java_lang_Compiler_disable)
KAFFE_NATIVE(java_lang_reflect_Constructor_getModifiers)
KAFFE_NATIVE(Java_java_lang_reflect_Constructor_newInstance)
KAFFE_NATIVE(java_text_DateFormat_format0)
KAFFE_NATIVE(java_lang_Double_toString)
KAFFE_NATIVE(java_lang_Double_valueOf0)
KAFFE_NATIVE(java_lang_Double_valueOf)
KAFFE_NATIVE(java_lang_Double_doubleToLongBits)
KAFFE_NATIVE(java_lang_Double_longBitsToDouble)
KAFFE_NATIVE(java_lang_reflect_Field_getModifiers)
KAFFE_NATIVE(java_lang_reflect_Field_get)
KAFFE_NATIVE(java_lang_reflect_Field_getBoolean)
KAFFE_NATIVE(java_lang_reflect_Field_getByte)
KAFFE_NATIVE(java_lang_reflect_Field_getChar)
KAFFE_NATIVE(java_lang_reflect_Field_getShort)
KAFFE_NATIVE(java_lang_reflect_Field_getInt)
KAFFE_NATIVE(java_lang_reflect_Field_getLong)
KAFFE_NATIVE(java_lang_reflect_Field_getFloat)
KAFFE_NATIVE(java_lang_reflect_Field_getDouble)
KAFFE_NATIVE(java_lang_reflect_Field_setBoolean)
KAFFE_NATIVE(java_lang_reflect_Field_setByte)
KAFFE_NATIVE(java_lang_reflect_Field_setChar)
KAFFE_NATIVE(java_lang_reflect_Field_setShort)
KAFFE_NATIVE(java_lang_reflect_Field_setInt)
KAFFE_NATIVE(java_lang_reflect_Field_setLong)
KAFFE_NATIVE(java_lang_reflect_Field_setFloat)
KAFFE_NATIVE(java_lang_reflect_Field_setDouble)
KAFFE_NATIVE(java_lang_reflect_Field_set)
KAFFE_NATIVE(java_io_File_isFile0)
KAFFE_NATIVE(java_io_File_isDirectory0)
KAFFE_NATIVE(java_io_File_exists0)
KAFFE_NATIVE(java_io_File_lastModified0)
KAFFE_NATIVE(java_io_File_canWrite0)
KAFFE_NATIVE(java_io_File_canRead0)
KAFFE_NATIVE(java_io_File_length0)
KAFFE_NATIVE(java_io_File_mkdir0)
KAFFE_NATIVE(java_io_File_renameTo0)
KAFFE_NATIVE(java_io_File_delete0)
KAFFE_NATIVE(java_io_File_rmdir0)
KAFFE_NATIVE(java_io_File_list0)
KAFFE_NATIVE(java_io_File_canonPath)
KAFFE_NATIVE(java_io_File_isAbsolute)
KAFFE_NATIVE(java_io_FileDescriptor_initSystemFD)
KAFFE_NATIVE(java_io_FileDescriptor_valid)
KAFFE_NATIVE(java_io_FileDescriptor_sync)
KAFFE_NATIVE(java_io_FileInputStream_open)
KAFFE_NATIVE(java_io_FileInputStream_close)
KAFFE_NATIVE(java_io_FileInputStream_readBytes)
KAFFE_NATIVE(java_io_FileInputStream_read)
KAFFE_NATIVE(java_io_FileInputStream_skip)
KAFFE_NATIVE(java_io_FileInputStream_available)
KAFFE_NATIVE(java_io_FileOutputStream_open)
KAFFE_NATIVE(java_io_FileOutputStream_openAppend)
KAFFE_NATIVE(java_io_FileOutputStream_close)
KAFFE_NATIVE(java_io_FileOutputStream_writeBytes)
KAFFE_NATIVE(java_io_FileOutputStream_write)
KAFFE_NATIVE(java_lang_Float_toString)
KAFFE_NATIVE(java_lang_Float_valueOf)
KAFFE_NATIVE(java_lang_Float_floatToIntBits)
KAFFE_NATIVE(java_lang_Float_intBitsToFloat)
KAFFE_NATIVE(java_lang_Math_sin)
KAFFE_NATIVE(java_lang_Math_cos)
KAFFE_NATIVE(java_lang_Math_tan)
KAFFE_NATIVE(java_lang_Math_asin)
KAFFE_NATIVE(java_lang_Math_acos)
KAFFE_NATIVE(java_lang_Math_atan)
KAFFE_NATIVE(java_lang_Math_exp)
KAFFE_NATIVE(java_lang_Math_log)
KAFFE_NATIVE(java_lang_Math_sqrt)
KAFFE_NATIVE(java_lang_Math_IEEEremainder)
KAFFE_NATIVE(java_lang_Math_ceil)
KAFFE_NATIVE(java_lang_Math_floor)
KAFFE_NATIVE(java_lang_Math_rint)
KAFFE_NATIVE(java_lang_Math_atan2)
KAFFE_NATIVE(java_lang_Math_pow)
KAFFE_NATIVE(java_lang_reflect_Method_getModifiers)
KAFFE_NATIVE(Java_java_lang_reflect_Method_invoke)
KAFFE_NATIVE(java_lang_Object_hashCode)
KAFFE_NATIVE(java_lang_Object_getClass)
KAFFE_NATIVE(java_lang_Object_notifyAll)
KAFFE_NATIVE(java_lang_Object_notify)
KAFFE_NATIVE(java_lang_Object_clone)
KAFFE_NATIVE(java_lang_Object_wait)
KAFFE_NATIVE(java_io_ObjectInputStream_loadClass0)
KAFFE_NATIVE(java_io_ObjectInputStream_inputClassFields)
KAFFE_NATIVE(java_io_ObjectInputStream_allocateNewObject)
KAFFE_NATIVE(java_io_ObjectInputStream_allocateNewArray)
KAFFE_NATIVE(java_io_ObjectInputStream_invokeObjectReader)
KAFFE_NATIVE(java_io_ObjectOutputStream_outputClassFields)
KAFFE_NATIVE(java_io_ObjectOutputStream_invokeObjectWriter)
KAFFE_NATIVE(java_io_ObjectStreamClass_getClassAccess)
KAFFE_NATIVE(java_io_ObjectStreamClass_getMethodSignatures)
KAFFE_NATIVE(java_io_ObjectStreamClass_getMethodAccess)
KAFFE_NATIVE(java_io_ObjectStreamClass_getFieldSignatures)
KAFFE_NATIVE(java_io_ObjectStreamClass_getFieldAccess)
KAFFE_NATIVE(java_io_ObjectStreamClass_getFields0)
KAFFE_NATIVE(java_io_ObjectStreamClass_getSerialVersionUID)
KAFFE_NATIVE(java_io_ObjectStreamClass_hasWriteObject)
KAFFE_NATIVE(java_io_RandomAccessFile_open)
KAFFE_NATIVE(java_io_RandomAccessFile_length)
KAFFE_NATIVE(java_io_RandomAccessFile_seek)
KAFFE_NATIVE(java_io_RandomAccessFile_readBytes)
KAFFE_NATIVE(java_io_RandomAccessFile_read)
KAFFE_NATIVE(java_io_RandomAccessFile_write)
KAFFE_NATIVE(java_io_RandomAccessFile_writeBytes)
KAFFE_NATIVE(java_io_RandomAccessFile_getFilePointer)
KAFFE_NATIVE(java_io_RandomAccessFile_close)
KAFFE_NATIVE(java_util_ResourceBundle_getClassContext)
KAFFE_NATIVE(java_lang_Runtime_initializeLinkerInternal)
KAFFE_NATIVE(java_lang_Runtime_buildLibName)
KAFFE_NATIVE(java_lang_Runtime_loadFileInternal)
KAFFE_NATIVE(java_lang_Runtime_exitInternal)
KAFFE_NATIVE(java_lang_Runtime_execInternal)
KAFFE_NATIVE(java_lang_Runtime_freeMemory)
KAFFE_NATIVE(java_lang_Runtime_totalMemory)
KAFFE_NATIVE(java_lang_Runtime_gc)
KAFFE_NATIVE(java_lang_Runtime_runFinalization)
KAFFE_NATIVE(java_lang_Runtime_traceInstructions)
KAFFE_NATIVE(java_lang_Runtime_traceMethodCalls)
KAFFE_NATIVE(java_lang_Runtime_runFinalizersOnExit0)
KAFFE_NATIVE(java_lang_SecurityManager_getClassContext)
KAFFE_NATIVE(java_lang_SecurityManager_currentClassLoader)
KAFFE_NATIVE(java_lang_SecurityManager_classDepth)
KAFFE_NATIVE(java_lang_SecurityManager_classLoaderDepth)
KAFFE_NATIVE(java_lang_SecurityManager_currentLoadedClass0)
KAFFE_NATIVE(java_lang_String_intern)
KAFFE_NATIVE(java_lang_String_unintern)
KAFFE_NATIVE(java_lang_System_arraycopy)
KAFFE_NATIVE(java_lang_System_initProperties)
KAFFE_NATIVE(java_lang_System_currentTimeMillis)
KAFFE_NATIVE(java_lang_System_setIn0)
KAFFE_NATIVE(java_lang_System_setOut0)
KAFFE_NATIVE(java_lang_System_setErr0)
KAFFE_NATIVE(java_lang_System_identityHashCode)
KAFFE_NATIVE(java_lang_Thread_currentThread)
KAFFE_NATIVE(java_lang_Thread_yield)
KAFFE_NATIVE(java_lang_Thread_sleep)
KAFFE_NATIVE(java_lang_Thread_start)
KAFFE_NATIVE(java_lang_Thread_isAlive)
KAFFE_NATIVE(java_lang_Thread_countStackFrames)
KAFFE_NATIVE(java_lang_Thread_setPriority0)
KAFFE_NATIVE(java_lang_Thread_stop0)
KAFFE_NATIVE(java_lang_Thread_suspend0)
KAFFE_NATIVE(java_lang_Thread_resume0)
KAFFE_NATIVE(java_lang_Thread_isInterrupted)
KAFFE_NATIVE(java_lang_Thread_interrupt0)
KAFFE_NATIVE(java_lang_Thread_finalize0)
KAFFE_NATIVE(java_lang_Throwable_fillInStackTrace)
KAFFE_NATIVE(java_lang_Throwable_printStackTrace0)
KAFFE_NATIVE(java_lang_UNIXProcess_forkAndExec)
KAFFE_NATIVE(java_lang_UNIXProcess_destroy)
KAFFE_NATIVE(java_lang_UNIXProcess_run)
KAFFE_NATIVE(java_lang_UNIXProcess_notifyReaders)
#if defined(DEBUG)
/*
 * Tests to make sure our sysdepCallMethod macros work, should help
 * in porting to new architectures.
 */
KAFFE_NATIVE(TestNative_test16int)
KAFFE_NATIVE(TestNative_test16long)
KAFFE_NATIVE(TestNative_test16intlong)
KAFFE_NATIVE(TestNative_test16float)
KAFFE_NATIVE(TestNative_test16double)
KAFFE_NATIVE(TestNative_test16floatdouble)
#endif

==> kaffe-1.0.b1_1998-08-19.tar.gz: kaffe-1.0.b1_1998-08-19/libraries/clib/native/external_wrappers.h <==
KAFFE_NATIVE(java_lang_reflect_Array_getLength)
KAFFE_NATIVE(java_lang_reflect_Array_get)
KAFFE_NATIVE(java_lang_reflect_Array_getBoolean)
KAFFE_NATIVE(java_lang_reflect_Array_getByte)
KAFFE_NATIVE(java_lang_reflect_Array_getChar)
KAFFE_NATIVE(java_lang_reflect_Array_getShort)
KAFFE_NATIVE(java_lang_reflect_Array_getInt)
KAFFE_NATIVE(java_lang_reflect_Array_getLong)
KAFFE_NATIVE(java_lang_reflect_Array_getFloat)
KAFFE_NATIVE(java_lang_reflect_Array_getDouble)
KAFFE_NATIVE(java_lang_reflect_Array_set)
KAFFE_NATIVE(java_lang_reflect_Array_setBoolean)
KAFFE_NATIVE(java_lang_reflect_Array_setByte)
KAFFE_NATIVE(java_lang_reflect_Array_setChar)
KAFFE_NATIVE(java_lang_reflect_Array_setShort)
KAFFE_NATIVE(java_lang_reflect_Array_setInt)
KAFFE_NATIVE(java_lang_reflect_Array_setLong)
KAFFE_NATIVE(java_lang_reflect_Array_setFloat)
KAFFE_NATIVE(java_lang_reflect_Array_setDouble)
KAFFE_NATIVE(java_lang_reflect_Array_newArray)
KAFFE_NATIVE(java_lang_reflect_Array_multiNewArray)
KAFFE_NATIVE(java_lang_Class_forName)
KAFFE_NATIVE(java_lang_Class_getName)
KAFFE_NATIVE(java_lang_Class_newInstance)
KAFFE_NATIVE(java_lang_Class_getSuperclass)
KAFFE_NATIVE(java_lang_Class_getInterfaces)
KAFFE_NATIVE(java_lang_Class_getClassLoader0)
KAFFE_NATIVE(java_lang_Class_isInterface)
KAFFE_NATIVE(java_lang_Class_isPrimitive)
KAFFE_NATIVE(java_lang_Class_isArray)
KAFFE_NATIVE(java_lang_Class_getComponentType)
KAFFE_NATIVE(java_lang_Class_isAssignableFrom)
KAFFE_NATIVE(java_lang_Class_getPrimitiveClass)
KAFFE_NATIVE(java_lang_Class_isInstance)
KAFFE_NATIVE(java_lang_Class_getModifiers)
KAFFE_NATIVE(java_lang_Class_getSigners)
KAFFE_NATIVE(java_lang_Class_setSigners)
KAFFE_NATIVE(java_lang_Class_getMethods0)
KAFFE_NATIVE(java_lang_Class_getConstructors0)
KAFFE_NATIVE(java_lang_Class_getFields0)
KAFFE_NATIVE(java_lang_Class_getMethod0)
KAFFE_NATIVE(java_lang_Class_getConstructor0)
KAFFE_NATIVE(java_lang_Class_getField0)
KAFFE_NATIVE(java_lang_ClassLoader_init)
KAFFE_NATIVE(java_lang_ClassLoader_defineClass0)
KAFFE_NATIVE(java_lang_ClassLoader_resolveClass0)
KAFFE_NATIVE(java_lang_ClassLoader_findSystemClass0)
KAFFE_NATIVE(java_lang_ClassLoader_getSystemResourceAsBytes0)
KAFFE_NATIVE(java_lang_Compiler_initialize)
KAFFE_NATIVE(java_lang_Compiler_compileClass)
KAFFE_NATIVE(java_lang_Compiler_compileClasses)
KAFFE_NATIVE(java_lang_Compiler_command)
KAFFE_NATIVE(java_lang_Compiler_enable)
KAFFE_NATIVE(java_lang_Compiler_disable)
KAFFE_NATIVE(java_lang_reflect_Constructor_getModifiers)
KAFFE_NATIVE(Java_java_lang_reflect_Constructor_newInstance)
KAFFE_NATIVE(java_text_DateFormat_format0)
KAFFE_NATIVE(java_lang_Double_toString)
KAFFE_NATIVE(java_lang_Double_valueOf0)
KAFFE_NATIVE(java_lang_Double_valueOf)
KAFFE_NATIVE(java_lang_Double_doubleToLongBits)
KAFFE_NATIVE(java_lang_Double_longBitsToDouble)
KAFFE_NATIVE(java_lang_reflect_Field_getModifiers)
KAFFE_NATIVE(java_lang_reflect_Field_get)
KAFFE_NATIVE(java_lang_reflect_Field_getBoolean)
KAFFE_NATIVE(java_lang_reflect_Field_getByte)
KAFFE_NATIVE(java_lang_reflect_Field_getChar)
KAFFE_NATIVE(java_lang_reflect_Field_getShort)
KAFFE_NATIVE(java_lang_reflect_Field_getInt)
KAFFE_NATIVE(java_lang_reflect_Field_getLong)
KAFFE_NATIVE(java_lang_reflect_Field_getFloat)
KAFFE_NATIVE(java_lang_reflect_Field_getDouble)
KAFFE_NATIVE(java_lang_reflect_Field_setBoolean)
KAFFE_NATIVE(java_lang_reflect_Field_setByte)
KAFFE_NATIVE(java_lang_reflect_Field_setChar)
KAFFE_NATIVE(java_lang_reflect_Field_setShort)
KAFFE_NATIVE(java_lang_reflect_Field_setInt)
KAFFE_NATIVE(java_lang_reflect_Field_setLong)
KAFFE_NATIVE(java_lang_reflect_Field_setFloat)
KAFFE_NATIVE(java_lang_reflect_Field_setDouble)
KAFFE_NATIVE(java_lang_reflect_Field_set)
KAFFE_NATIVE(java_io_File_isFile0)
KAFFE_NATIVE(java_io_File_isDirectory0)
KAFFE_NATIVE(java_io_File_exists0)
KAFFE_NATIVE(java_io_File_lastModified0)
KAFFE_NATIVE(java_io_File_canWrite0)
KAFFE_NATIVE(java_io_File_canRead0)
KAFFE_NATIVE(java_io_File_length0)
KAFFE_NATIVE(java_io_File_mkdir0)
KAFFE_NATIVE(java_io_File_renameTo0)
KAFFE_NATIVE(java_io_File_delete0)
KAFFE_NATIVE(java_io_File_rmdir0)
KAFFE_NATIVE(java_io_File_list0)
KAFFE_NATIVE(java_io_File_canonPath)
KAFFE_NATIVE(java_io_File_isAbsolute)
KAFFE_NATIVE(java_io_FileDescriptor_initSystemFD)
KAFFE_NATIVE(java_io_FileDescriptor_valid)
KAFFE_NATIVE(java_io_FileDescriptor_sync)
KAFFE_NATIVE(java_io_FileInputStream_open)
KAFFE_NATIVE(java_io_FileInputStream_close)
KAFFE_NATIVE(java_io_FileInputStream_readBytes)
KAFFE_NATIVE(java_io_FileInputStream_read)
KAFFE_NATIVE(java_io_FileInputStream_skip)
KAFFE_NATIVE(java_io_FileInputStream_available)
KAFFE_NATIVE(java_io_FileOutputStream_open)
KAFFE_NATIVE(java_io_FileOutputStream_openAppend)
KAFFE_NATIVE(java_io_FileOutputStream_close)
KAFFE_NATIVE(java_io_FileOutputStream_writeBytes)
KAFFE_NATIVE(java_io_FileOutputStream_write)
KAFFE_NATIVE(java_lang_Float_toString)
KAFFE_NATIVE(java_lang_Float_valueOf)
KAFFE_NATIVE(java_lang_Float_floatToIntBits)
KAFFE_NATIVE(java_lang_Float_intBitsToFloat)
KAFFE_NATIVE(java_lang_Math_sin)
KAFFE_NATIVE(java_lang_Math_cos)
KAFFE_NATIVE(java_lang_Math_tan)
KAFFE_NATIVE(java_lang_Math_asin)
KAFFE_NATIVE(java_lang_Math_acos)
KAFFE_NATIVE(java_lang_Math_atan)
KAFFE_NATIVE(java_lang_Math_exp)
KAFFE_NATIVE(java_lang_Math_log)
KAFFE_NATIVE(java_lang_Math_sqrt)
KAFFE_NATIVE(java_lang_Math_IEEEremainder)
KAFFE_NATIVE(java_lang_Math_ceil)
KAFFE_NATIVE(java_lang_Math_floor)
KAFFE_NATIVE(java_lang_Math_rint)
KAFFE_NATIVE(java_lang_Math_atan2)
KAFFE_NATIVE(java_lang_Math_pow)
KAFFE_NATIVE(java_lang_reflect_Method_getModifiers)
KAFFE_NATIVE(Java_java_lang_reflect_Method_invoke)
KAFFE_NATIVE(java_lang_Object_hashCode)
KAFFE_NATIVE(java_lang_Object_getClass)
KAFFE_NATIVE(java_lang_Object_notifyAll)
KAFFE_NATIVE(java_lang_Object_notify)
KAFFE_NATIVE(java_lang_Object_clone)
KAFFE_NATIVE(java_lang_Object_wait0)
KAFFE_NATIVE(java_io_ObjectInputStream_loadClass0)
KAFFE_NATIVE(java_io_ObjectInputStream_inputClassFields)
KAFFE_NATIVE(java_io_ObjectInputStream_allocateNewObject)
KAFFE_NATIVE(java_io_ObjectInputStream_allocateNewArray)
KAFFE_NATIVE(java_io_ObjectInputStream_invokeObjectReader)
KAFFE_NATIVE(java_io_ObjectOutputStream_outputClassFields)
KAFFE_NATIVE(java_io_ObjectOutputStream_invokeObjectWriter)
KAFFE_NATIVE(java_io_ObjectStreamClass_getClassAccess)
KAFFE_NATIVE(java_io_ObjectStreamClass_getMethodSignatures)
KAFFE_NATIVE(java_io_ObjectStreamClass_getMethodAccess)
KAFFE_NATIVE(java_io_ObjectStreamClass_getFieldSignatures)
KAFFE_NATIVE(java_io_ObjectStreamClass_getFieldAccess)
KAFFE_NATIVE(java_io_ObjectStreamClass_getFields0)
KAFFE_NATIVE(java_io_ObjectStreamClass_getSerialVersionUID)
KAFFE_NATIVE(java_io_ObjectStreamClass_hasWriteObject)
KAFFE_NATIVE(java_io_RandomAccessFile_open)
KAFFE_NATIVE(java_io_RandomAccessFile_length)
KAFFE_NATIVE(java_io_RandomAccessFile_seek)
KAFFE_NATIVE(java_io_RandomAccessFile_readBytes)
KAFFE_NATIVE(java_io_RandomAccessFile_read)
KAFFE_NATIVE(java_io_RandomAccessFile_write)
KAFFE_NATIVE(java_io_RandomAccessFile_writeBytes)
KAFFE_NATIVE(java_io_RandomAccessFile_getFilePointer)
KAFFE_NATIVE(java_io_RandomAccessFile_close)
KAFFE_NATIVE(java_util_ResourceBundle_getClassContext)
KAFFE_NATIVE(java_lang_Runtime_initializeLinkerInternal)
KAFFE_NATIVE(java_lang_Runtime_buildLibName)
KAFFE_NATIVE(java_lang_Runtime_loadFileInternal)
KAFFE_NATIVE(java_lang_Runtime_exitInternal)
KAFFE_NATIVE(java_lang_Runtime_execInternal)
KAFFE_NATIVE(java_lang_Runtime_freeMemory)
KAFFE_NATIVE(java_lang_Runtime_totalMemory)
KAFFE_NATIVE(java_lang_Runtime_gc)
KAFFE_NATIVE(java_lang_Runtime_runFinalization)
KAFFE_NATIVE(java_lang_Runtime_traceInstructions)
KAFFE_NATIVE(java_lang_Runtime_traceMethodCalls)
KAFFE_NATIVE(java_lang_Runtime_runFinalizersOnExit0)
KAFFE_NATIVE(java_lang_SecurityManager_getClassContext)
KAFFE_NATIVE(java_lang_SecurityManager_currentClassLoader)
KAFFE_NATIVE(java_lang_SecurityManager_classDepth)
KAFFE_NATIVE(java_lang_SecurityManager_classLoaderDepth)
KAFFE_NATIVE(java_lang_SecurityManager_currentLoadedClass0)
KAFFE_NATIVE(java_lang_String_intern)
KAFFE_NATIVE(java_lang_String_unintern)
KAFFE_NATIVE(java_lang_System_arraycopy)
KAFFE_NATIVE(java_lang_System_initProperties)
KAFFE_NATIVE(java_lang_System_currentTimeMillis)
KAFFE_NATIVE(java_lang_System_setIn0)
KAFFE_NATIVE(java_lang_System_setOut0)
KAFFE_NATIVE(java_lang_System_setErr0)
KAFFE_NATIVE(java_lang_System_identityHashCode)
KAFFE_NATIVE(java_lang_Thread_currentThread)
KAFFE_NATIVE(java_lang_Thread_yield)
KAFFE_NATIVE(java_lang_Thread_sleep0)
KAFFE_NATIVE(java_lang_Thread_start)
KAFFE_NATIVE(java_lang_Thread_isAlive)
KAFFE_NATIVE(java_lang_Thread_countStackFrames)
KAFFE_NATIVE(java_lang_Thread_setPriority0)
KAFFE_NATIVE(java_lang_Thread_stop0)
KAFFE_NATIVE(java_lang_Thread_suspend0)
KAFFE_NATIVE(java_lang_Thread_resume0)
KAFFE_NATIVE(java_lang_Thread_isInterrupted)
KAFFE_NATIVE(java_lang_Thread_interrupt0)
KAFFE_NATIVE(java_lang_Thread_finalize0)
KAFFE_NATIVE(java_lang_Throwable_fillInStackTrace)
KAFFE_NATIVE(java_lang_Throwable_printStackTrace0)
KAFFE_NATIVE(Java_kaffe_lang_UNIXProcess_forkAndExec)
KAFFE_NATIVE(Java_kaffe_lang_UNIXProcess_destroy)
KAFFE_NATIVE(Java_kaffe_lang_UNIXProcess_run)
KAFFE_NATIVE(Java_kaffe_io_CharToByteDefault_convert)
KAFFE_NATIVE(Java_kaffe_io_ByteToCharDefault_convert)
KAFFE_NATIVE(java_util_zip_ZipFile_openZipFile0)
KAFFE_NATIVE(java_util_zip_ZipFile_closeZipFile0)
KAFFE_NATIVE(java_util_zip_ZipFile_getZipEntry0)
KAFFE_NATIVE(java_util_zip_ZipFile_getZipData0)
KAFFE_NATIVE(java_util_zip_ZipFile_getZipEntries0)
KAFFE_NATIVE(java_text_DateFormat_format0)
#if defined(DEBUG)
/*
 * Tests to make sure our sysdepCallMethod macros work, should help
 * in porting to new architectures.
 */
KAFFE_NATIVE(TestNative_test16int)
KAFFE_NATIVE(TestNative_test16long)
KAFFE_NATIVE(TestNative_test16intlong)
KAFFE_NATIVE(TestNative_test16float)
KAFFE_NATIVE(TestNative_test16double)
KAFFE_NATIVE(TestNative_test16floatdouble)
#endif
